@@ -9,7 +9,7 @@ from disqusapi import DisqusAPI
 class Command(BaseCommand):
 
     # Displayed from 'manage.py help mycommand'
-    help = "That's Your help message"
+    help = "Import Disqus comments into local database"
 
     # make_option requires options in optparse format
     option_list = BaseCommand.option_list  + (
