@@ -34,8 +34,11 @@ def tla_list(context):
 
 """
 Template:
-{% load cache %}
 
+Now:
+{% tla_list %}
+
+Before:
 {% cache 21600 tla %}
 <ul id="tla">
 {% if links %}
