@@ -16,6 +16,7 @@ from django.conf import settings as conf
 from django.views.generic import ListView, DetailView
 from django.contrib.sites.models import get_current_site
 from django.core.urlresolvers import reverse
+from django.contrib.sitemaps import Sitemap
 
 from disqusapi import DisqusAPI
 from disqusapi import Paginator
@@ -211,3 +212,18 @@ class AJAXArchive(ListView):
             'results': results,
         })
         return context
+
+
+class BlogSitemap(Sitemap):
+
+    changefreq = "never"
+    priority = 0.5
+
+    def items(self):
+        timenow = datetime.datetime.now()
+        return mymodels.Post.objects.filter(
+            status=1,
+            creation_date__lte=timenow).order_by('-creation_date')
+
+    def lastmod(self, obj):
+        return obj.creation_date
